==> scilab-2.1.1.tar.gz: scilab-2.1.1/routines/xsci/help/help-text1.h <==
"  and   - logical and ",
"  ans   - answer ",
"  apropos   - searches keywords in Scilab help  ",
"  argn   - number of arguments in a function call ",
"  \\   - left matrix division backslash ",
"  Scilab object: boolean    - boolean variables and operators & | ~ ",
"  [,]   - left and right brackets ",
"  break   - keyword to interrupt loops ",
"  case   - keyword used in select ",
"  ceil   - rounding up ",
"  clear   - kills variables ",
"  clearfun   - remove primitive. ",
"  code2str   - returns character string associated with Scilab integer codes. ",
"  coeff   - coefficients of matrix polynomial ",
"  :   - colon operator ",
"   ,   - comma ",
"  comments   - comments ",
"  comp   -  function compilation ",
"  deff   - on-line definition of function ",
"  degree   - degree of polynomial matrix ",
"  delbpt   - delete breakpoint ",
"  diary   - diary of session ",
"  disp   - displays variables  ",
"  dispbpt   - display breakpoints ",
"  else   - keyword in if-then-else ",
"  elseif   - keyword in if-then-else ",
"  []   - empty matrix ",
"  end   - end keyword ",
"  =   - equal sign ",
"  errcatch   - error trapping ",
"  errclear   - error clearing ",
"  error   - error messages  ",
"  evstr   - evaluation of expressions ",
"  exec   - script file execution ",
"  exists   - checks variable  existence ",
"  exit   -  Scilab quit ",
"  external   - Scilab Object, external function or routine ",
"  eye   - identity matrix ",
"  feval   - multiple evaluation ",
"  file   - file management ",
"  find   - find indices of  boolean vector or matrix true elements ",
"  fix   - rounding towards zero ",
"  floor   - rounding down ",
"  for   - language keyword for loops ",
"  format   - printing format ",
"  fort   - fortran or C user routines call ",
"  printf,fprintf,sprintf   - Emulator of C language printf functions ",
"  scanf, fscanf, sscanf   - Converts formatted input ",
"  Scilab object : function   - Scilab procedure ",
"  funptr   - coding of  primitives ( wizard stuff ) ",
"  getenv   - get the value of an environnement variable ",
"  getf   - loading of function ",
"  getpid   - get Scilab process identificator ",
"  ^,exp   - exponentiation ",
"  help   - on-line help command ",
"  host   - unix call ",
"  if then else   - conditional execution ",
"  imag   - imaginary part ",
"  int   - integer part ",
"  iserror   - error test ",
"  keyboard   - keyborad commands ",
"  [   - left bracket ",
"  length   - length of object ",
"   <   - lower ",
"  lib   - library definition ",
"  lines   - rows and columns used for display ",
"  link   - dynamic link ",
"  Scilab object: list   - list definition ",
"  load   - load saved variable ",
"  Scilab object : macro   - Scilab procedure ",
"  Scilab object: matrix   - matrices in Scilab ",
"  matrix   - vector to matrix conversion ",
"  max   - maximum ",
"  maxi   - maximum ",
"  min   - minimum  ",
"  mini   - minimum  ",
"  -   - the minus operation ",
"  mode   - select a mode in exec file ",
"  newfun   - add a name in the table of functions ",
"  null   - delete an element in a list ",
"  ones   - matrix made of ones ",
"  or |   - logical or ",
"  ( )   - left and right parenthesis ",
"  part   - extraction of strings ",
"  pause   - pause mode, invoke keyboard ",
"  %   - percent ",
"  +       -      addition ",
"  poly   - polynomial definition ",
"  ^    - power operation  ",
"  predef   - variable protection ",
"  print   - prints variables  in a file  ",
"  printf,fprintf,sprintf   - Emulator of C language printf functions ",
"  quit   - decrease the pause level or exit ",
"   '   - transpose of matrix ",
"  rand   - random number generator ",
"  Scilab object : rationals   - rational in Scilab ",
"  read   - matrices read ",
"  readb   - binary read  ",
"  real   - real part ",
"  resume   - return or resume  ",
"  return   - return or resume  ",
"  round   - rounding ",
"  save   - saving variables ",
"  scanf, fscanf, sscanf   - Converts formatted input ",
"  scilab    - Major unix script to execute Scilab and miscellaneous tools ",
"  scilink   - Unix script to relink Scilab ",
"  select   - select keyword  ",
"  ;   -  ending expression and row separator ",
"  setbpt   - setting breakpoints  ",
"  sign   - sign function ",
"  size   - size of objects ",
"  /   - right division and feed back ",
"  printf,fprintf,sprintf   - Emulator of C language printf functions ",
"  scanf, fscanf, sscanf   - Converts formatted input ",
"  *   - multiplication  ",
"  startup   - startup file  ",
"  str2code   - return scilab integer codes associated with a character string ",
"  string   - conversion to string ",
"  Scilab object:string   - character strings ",
"  ~   - logical not ",
"  type   - variable type ",
"  unix   - shell (sh) command execution ",
"  unix_g   - shell (sh) command execution, output redirected to a variable ",
"  unix_s   - shell (sh) command execution, no output ",
"  unix_w   - shell (sh) command execution, output redirected to scilab window ",
"  unix_x   - shell (sh) command execution, output redirected to a window ",
"  user   - interfacing a fortran routine ",
"  varn   - symbolic variable of a polynomial ",
"  what   - list the Scilab primitives ",
"  where   - get current instruction calling tree ",
"  whereami   - display current instruction calling tree ",
"  whereis   - name of library containing a function ",
"  while   - while keyword  ",
"  who   - listing of variables ",
"  writb   - binary write ",
"  write   -  write in a formatted file ",

==> scilab_2.2.orig.tar.gz: scilab-2.2.orig/routines/xsci/help/help-text1.h <==
"  addinter   - new functions interface incremental linking at run time ",
"  and   - logical and ",
"  ans   - answer ",
"  apropos   - searches keywords in Scilab help  ",
"  argn   - number of arguments in a function call ",
"  \\   - left matrix division backslash ",
"  Scilab object: boolean    - boolean variables and operators & | ~ ",
"  [,]   - left and right brackets ",
"  break   - keyword to interrupt loops ",
"  case   - keyword used in select ",
"  ceil   - rounding up ",
"  clear   - kills variables ",
"  clearfun   - remove primitive. ",
"  code2str   - returns character string associated with Scilab integer codes. ",
"  coeff   - coefficients of matrix polynomial ",
"  :   - colon operator ",
"   ,   - comma ",
"  comments   - comments ",
"  comp   -  function compilation ",
"  deff   - on-line definition of function ",
"  degree   - degree of polynomial matrix ",
"  delbpt   - delete breakpoint ",
"  diary   - diary of session ",
"  disp   - displays variables  ",
"  dispbpt   - display breakpoints ",
"  else   - keyword in if-then-else ",
"  elseif   - keyword in if-then-else ",
"  []   - empty matrix ",
"  end   - end keyword ",
"  =   - equal sign ",
"  errcatch   - error trapping ",
"  errclear   - error clearing ",
"  error   - error messages  ",
"  evstr   - evaluation of expressions ",
"  exec   - script file execution ",
"  exists   - checks variable  existence ",
"  exit   -  Scilab quit ",
"  external   - Scilab Object, external function or routine ",
"  eye   - identity matrix ",
"  feval   - multiple evaluation ",
"  file   - file management ",
"  find   - find indices of  boolean vector or matrix true elements ",
"  fix   - rounding towards zero ",
"  floor   - rounding down ",
"  for   - language keyword for loops ",
"  format   - printing format ",
"  fort   - fortran or C user routines call ",
"  printf,fprintf,sprintf   - Emulator of C language printf functions ",
"  scanf, fscanf, sscanf   - Converts formatted input ",
"  Scilab object : function   - Scilab procedure ",
"  funptr   - coding of  primitives ( wizard stuff ) ",
"  getenv   - get the value of an environnement variable ",
"  getf   - loading of function ",
"  getpid   - get Scilab process identificator ",
"  ^,exp   - exponentiation ",
"  help   - on-line help command ",
"  host   - unix call ",
"  if then else   - conditional execution ",
"  imag   - imaginary part ",
"  int   - integer part ",
"  iserror   - error test ",
"  keyboard   - keyborad commands ",
"  [   - left bracket ",
"  length   - length of object ",
"   <   - lower ",
"  lib   - library definition ",
"  lines   - rows and columns used for display ",
"  link   - dynamic link ",
"  Scilab object: list   - list definition ",
"  load   - load saved variable ",
"  Scilab object : macro   - Scilab procedure ",
"  Scilab object: matrix   - matrices in Scilab ",
"  matrix   - vector to matrix conversion ",
"  max   - maximum ",
"  maxi   - maximum ",
"  min   - minimum  ",
"  mini   - minimum  ",
"  -   - the minus operation ",
"  mode   - select a mode in exec file ",
"  newfun   - add a name in the table of functions ",
"  null   - delete an element in a list ",
"  ones   - matrix made of ones ",
"  or |   - logical or ",
"  ( )   - left and right parenthesis ",
"  part   - extraction of strings ",
"  pause   - pause mode, invoke keyboard ",
"  %   - percent ",
"  +       -      addition ",
"  poly   - polynomial definition ",
"  ^    - power operation  ",
"  predef   - variable protection ",
"  print   - prints variables  in a file  ",
"  printf,fprintf,sprintf   - Emulator of C language printf functions ",
"  quit   - decrease the pause level or exit ",
"   '   - transpose of matrix ",
"  rand   - random number generator ",
"  rat   - Floating point rational approximation  ",
"  Scilab object : rationals   - rational in Scilab ",
"  read   - matrices read ",
"  readb   - binary read  ",
"  real   - real part ",
"  resume   - return or resume  ",
"  return   - return or resume  ",
"  round   - rounding ",
"  save   - saving variables ",
"  scanf, fscanf, sscanf   - Converts formatted input ",
"  scilab    - Major unix script to execute Scilab and miscellaneous tools ",
"  scilink   - Unix script to relink Scilab ",
"  select   - select keyword  ",
"  ;   -  ending expression and row separator ",
"  setbpt   - setting breakpoints  ",
"  sign   - sign function ",
"  size   - size of objects ",
"  /   - right division and feed back ",
"  printf,fprintf,sprintf   - Emulator of C language printf functions ",
"  scanf, fscanf, sscanf   - Converts formatted input ",
"  stacksize   - set scilab stack size  ",
"  *   - multiplication  ",
"  startup   - startup file  ",
"  str2code   - return scilab integer codes associated with a character string ",
"  string   - conversion to string ",
"  Scilab object:string   - character strings ",
"  ~   - logical not ",
"  Scilab object: tlist   - typed list definition ",
"  type   - variable type ",
"  unix   - shell (sh) command execution ",
"  unix_g   - shell (sh) command execution, output redirected to a variable ",
"  unix_s   - shell (sh) command execution, no output ",
"  unix_w   - shell (sh) command execution, output redirected to scilab window ",
"  unix_x   - shell (sh) command execution, output redirected to a window ",
"  user   - interfacing a fortran routine ",
"  varn   - symbolic variable of a polynomial ",
"  what   - list the Scilab primitives ",
"  where   - get current instruction calling tree ",
"  whereami   - display current instruction calling tree ",
"  whereis   - name of library containing a function ",
"  while   - while keyword  ",
"  who   - listing of variables ",
"  writb   - binary write ",
"  write   -  write in a formatted file ",
